==> cursors_extended-fabric-4.1.0%2B1.21.9-sources.jar: io/github/fishstiz/cursors_extended/gui/renderstate/GuiColoredRectRenderState.java <==
package io.github.fishstiz.cursors_extended.gui.renderstate;

import com.mojang.blaze3d.pipeline.RenderPipeline;
import net.minecraft.class_10799;
import net.minecraft.class_11231;
import net.minecraft.class_11242;
import net.minecraft.class_11244;
import net.minecraft.class_4588;
import net.minecraft.class_8030;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;
import org.joml.Matrix3x2f;

/**
 * Copied from {@link class_11242}, changed bounds to float
 */
public record GuiColoredRectRenderState(
        Matrix3x2f matrix3x2f,
        float x0,
        float y0,
        float x1,
        float y1,
        int color,
        class_8030 bounds
) implements class_11244 {
    public GuiColoredRectRenderState(
            Matrix3x2f matrix3x2f,
            float x0,
            float y0,
            float x1,
            float y1,
            int color
    ) {
        this(matrix3x2f, x0, y0, x1, y1, color, getBounds(x0, y0, x1, y1, matrix3x2f));
    }

    @Override
    public void method_70917(class_4588 vertexConsumer) {
        vertexConsumer.method_70815(this.matrix3x2f(), this.x0(), this.y0()).method_39415(this.color());
        vertexConsumer.method_70815(this.matrix3x2f(), this.x0(), this.y1()).method_39415(this.color());
        vertexConsumer.method_70815(this.matrix3x2f(), this.x1(), this.y1()).method_39415(this.color());
        vertexConsumer.method_70815(this.matrix3x2f(), this.x1(), this.y0()).method_39415(this.color());
    }

    @Override
    public @NotNull RenderPipeline comp_4055() {
        return class_10799.field_56879;
    }

    @Override
    public @NotNull class_11231 comp_4056() {
        return class_11231.method_70899();
    }

    @Override
    public @Nullable class_8030 comp_4069() {
        return null;
    }

    private static class_8030 getBounds(float x0, float y0, float x1, float y1, Matrix3x2f pose) {
        return new class_8030((int) x0, (int) y0, (int) (x1 - x0), (int) (y1 - y0)).method_71523(pose);
    }
}

==> cursors_extended-fabric-4.1.4%2B1.21.11-sources.jar: io/github/fishstiz/cursors_extended/gui/renderstate/GuiColoredRectRenderState.java <==
package io.github.fishstiz.cursors_extended.gui.renderstate;

import com.mojang.blaze3d.pipeline.RenderPipeline;
import net.minecraft.class_10799;
import net.minecraft.class_11231;
import net.minecraft.class_11242;
import net.minecraft.class_11244;
import net.minecraft.class_4588;
import net.minecraft.class_8030;
import org.joml.Matrix3x2f;
import org.jspecify.annotations.NonNull;
import org.jspecify.annotations.Nullable;

/**
 * Copied from {@link class_11242}, changed bounds to float
 */
public record GuiColoredRectRenderState(
        Matrix3x2f matrix3x2f,
        float x0,
        float y0,
        float x1,
        float y1,
        int color,
        class_8030 bounds
) implements class_11244 {
    public GuiColoredRectRenderState(
            Matrix3x2f matrix3x2f,
            float x0,
            float y0,
            float x1,
            float y1,
            int color
    ) {
        this(matrix3x2f, x0, y0, x1, y1, color, getBounds(x0, y0, x1, y1, matrix3x2f));
    }

    @Override
    public void method_70917(class_4588 vertexConsumer) {
        vertexConsumer.method_70815(this.matrix3x2f(), this.x0(), this.y0()).method_39415(this.color());
        vertexConsumer.method_70815(this.matrix3x2f(), this.x0(), this.y1()).method_39415(this.color());
        vertexConsumer.method_70815(this.matrix3x2f(), this.x1(), this.y1()).method_39415(this.color());
        vertexConsumer.method_70815(this.matrix3x2f(), this.x1(), this.y0()).method_39415(this.color());
    }

    @Override
    public @NonNull RenderPipeline comp_4055() {
        return class_10799.field_56879;
    }

    @Override
    public @NonNull class_11231 comp_4056() {
        return class_11231.method_70899();
    }

    @Override
    public @Nullable class_8030 comp_4069() {
        return null;
    }

    private static class_8030 getBounds(float x0, float y0, float x1, float y1, Matrix3x2f pose) {
        return new class_8030((int) x0, (int) y0, (int) (x1 - x0), (int) (y1 - y0)).method_71523(pose);
    }
}
